import csv
from JoPasteOutbreak.city import City
import json

class Event_Card:
    def __init__(self, name, event_type , area_affected, r0_difference, unemployment_rate_difference):
        self._name = name
        self._event_type = event_type
        self._area_affected = area_affected
        self.r0_difference = r0_difference
        self.unemployment_rate_difference = unemployment_rate_difference
        self._affected_cities = []

    def apply_to_affected_cities(self, City:City):
        City.r0 = round( City.r0 + self.r0_difference, 2)
        City.unemployment_rate = round(City.unemployment_rate + self.unemployment_rate_difference, 2)

    def apply_federally(self, list_of_citys):
        for city in list_of_citys:
            self.apply_to_affected_cities(city)

def load_events_from_json(file_path: str, events_list: list[Event_Card]):
    file = open(file_path, "r")
    loaded_events_list = json.load(file)
    for json_event in loaded_events_list:
        event = Event_Card(json_event["name"], json_event["event_type"], 
        json_event["area_affected"], json_event["r0_difference"], 
        json_event["unemployment_rate_difference"])
        if json_event["area_affected"] == "local":
            event._affected_cities = json_event["affected_cities"]
        events_list.append(event)
    file.close()

def load_events_from_csv(file_path: str, events_list: list[Event_Card]):
    with open(file_path, 'r') as file:
        csvreader = csv.reader(file)
        next(csvreader)
        for event in csvreader:
            event_obj = Event_Card(event[0], event[1], event[2], float(event[3]), float(event[4]))
            if event[2] == "local":
                event_obj._affected_cities = event[5:12]
            events_list.append(event_obj)
    file.close()


from random import randint
import json
import csv

class City:
    def __init__(self, name, population, r0):
        self._name = name
        self._population = population
        self.r0 = r0
        self.unemployment_rate = round(randint(7,12), 2)
        self.set_infected_population(self.r0, self._population)
        self.set_open_hires(self.unemployment_rate, self._population)

    def set_open_hires(self, unemployment_rate, _population):
        self._open_hires = round((unemployment_rate / 100) * _population,2 )

    def set_infected_population(self, r0, _population):
        self._infected_population = int(round(_population / r0, 0))

def load_cities_from_json(file_path: str, cities_list: list[City]):
    file = open(file_path, "r")
    loaded_cities_list = json.load(file)
    for json_city in loaded_cities_list:
        city = City(json_city["name"], 
        json_city["population"], 
        json_city["r0"])
        cities_list.append(city)
    file.close()

def load_cities_from_csv(file_path: str, cities_list: list[City]):
    with open(file_path, 'r') as file:
        csvreader = csv.reader(file)
        next(csvreader)
        for city in csvreader:
            city_obj = City(city[0], int(city[1]), float(city[2]))
            cities_list.append(city_obj)
    file.close()


class Virus:
    def __init__(self, name, long_name, r0, mortality_rate):
        self._name = name
        self._long_name = long_name
        self._r0  = r0
        self._mortality_rate = mortality_rate
    def get_name(self):
        return self._name
    def get_long_name(self):
        return self._long_name
    def get_r0(self):
        return self._r0
    def get_mortality_rate(self):
        return self._mortality_rate
